@@ -3,6 +3,7 @@
 #' This function returns and plots frequency of missing values for each feature.
 #' @param data input data
 #' @param group missing profile band taking a list of group name and group upper bounds. Default is \code{list("Good" = 0.05, "OK" = 0.4, "Bad" = 0.8, "Remove" = 1)}.
+#' @param group_color bar color list for each of the group. Default is \code{list("Good" = "#1B9E77", "OK" = "#E6AB02", "Bad" = "#D95F02", "Remove" = "#E41A1C")}.
 #' @param missing_only plot features with missing values only? Default is \code{FALSE}.
 #' @param geom_label_args a list of other arguments to \link{geom_label}
 #' @param title plot title
@@ -19,18 +20,23 @@
 #' 
 #' ## Customize band
 #' plot_missing(airquality, group = list("B1" = 0, "B2" = 0.06, "B3" = 1))
+#' plot_missing(airquality, group = list("Awesome!" = 0.2, "Oh no!" = 1),
+#' group_color = list("Awesome!" = "green", "Oh no!" = "red"))
 #' 
 #' ## Shrink geom_label size
 #' library(ggplot2)
-#' plot_missing(airquality, geom_label_args = list("size" = 2, "label.padding" = unit(0.1, "lines")))
+#' plot_missing(airquality, geom_label_args = list("size" = 2,
+#' "label.padding" = unit(0.1, "lines")))
 
 plot_missing <- function(data,
                          group = list("Good" = 0.05, "OK" = 0.4, "Bad" = 0.8, "Remove" = 1),
+                         group_color = list("Good" = "#1B9E77", "OK" = "#E6AB02", "Bad" = "#D95F02", "Remove" = "#E41A1C"),
                          missing_only = FALSE,
                          geom_label_args = list(),
                          title = NULL,
                          ggtheme = theme_gray(),
                          theme_config = list("legend.position" = c("bottom"))) {
+  
   ## Declare variable first to pass R CMD check
   num_missing <- pct_missing <- Band <- NULL
   ## Profile missing values
@@ -45,10 +51,24 @@ plot_missing <- function(data,
       missing_value[pct_missing > group[[i-1]] & pct_missing <= group[[i]], Band := names(group)[i]]
     }
   }))
+  
+  ## Determine ordinal levels from group supplied
+  ordinal_levels <- names(group[sort.list(unlist(group))])
+  
+  ## Convert character to ordered factor to support ordinal legend
+  missing_value[, Band := factor(Band, levels = ordinal_levels, ordered = TRUE)]
+  
+  ## Determine bar fill color
+  if (length(setdiff(names(group), names(group_color))) > 0) {
+    bar_fill <- scale_fill_discrete("Band")
+  } else {
+    bar_fill <- scale_fill_manual(values = group_color)
+  }
+  
   ## Create ggplot object
   output <- ggplot(missing_value, aes_string(x = "feature", y = "num_missing", fill = "Band")) +
     geom_bar(stat = "identity") +
-    scale_fill_discrete("Band") +
+    bar_fill +
     coord_flip() +
     xlab("Features") + ylab("Missing Rows") +
     guides(fill = guide_legend(override.aes = aes(label = "")))
